@@ -12,8 +12,6 @@
 #include "importcertificatefromfilecommand.h"
 #include "importcertificatescommand_p.h"
 
-#include "utils/filedialog.h"
-
 #include <QGpgME/Protocol>
 #include <QGpgME/ImportJob>
 
@@ -26,6 +24,7 @@
 #include <KConfigGroup>
 
 #include <QFile>
+#include <QFileDialog>
 #include <QString>
 #include <QWidget>
 #include <QFileInfo>
@@ -122,32 +121,38 @@ void ImportCertificateFromFileCommand::doStart()
         return;
     }
 
+    d->setProgressWindowTitle(i18nc("@title:window", "Importing Certificates"));
+    d->setProgressLabelText(i18np("Importing certificates from 1 file...",
+                                  "Importing certificates from %1 files...",
+                                  d->files.size()));
+
     //TODO: use KIO here
     d->setWaitForMoreJobs(true);
     for (const QString &fn : std::as_const(d->files)) {
         QFile in(fn);
         if (!in.open(QIODevice::ReadOnly)) {
             d->error(i18n("Could not open file %1 for reading: %2", in.fileName(), in.errorString()), i18n("Certificate Import Failed"));
-            d->importResult(ImportResult(), fn);
+            d->importResult({fn, GpgME::UnknownProtocol, ImportType::Local, ImportResult{}});
             continue;
         }
         const auto data = in.readAll();
         d->startImport(GpgME::OpenPGP, data, fn);
         d->startImport(GpgME::CMS, data, fn);
+        d->importGroupsFromFile(fn);
     }
     d->setWaitForMoreJobs(false);
 }
 
 static QStringList get_file_name(QWidget *parent)
 {
-    const QString certificateFilter = i18n("Certificates") + QLatin1String(" (*.asc *.cer *.cert *.crt *.der *.pem *.gpg *.p7c *.p12 *.pfx *.pgp)");
+    const QString certificateFilter = i18n("Certificates") + QLatin1String(" (*.asc *.cer *.cert *.crt *.der *.pem *.gpg *.p7c *.p12 *.pfx *.pgp *.kgrp)");
     const QString anyFilesFilter = i18n("Any files") + QLatin1String(" (*)");
     QString previousDir;
     if (const KSharedConfig::Ptr config = KSharedConfig::openConfig()) {
         const KConfigGroup group(config, "Import Certificate");
         previousDir = group.readPathEntry("last-open-file-directory", QDir::homePath());
     }
-    const QStringList files = Kleo::FileDialog::getOpenFileNames(parent, i18n("Select Certificate File"), previousDir, certificateFilter + QLatin1String(";;") + anyFilesFilter);
+    const QStringList files = QFileDialog::getOpenFileNames(parent, i18n("Select Certificate File"), previousDir, certificateFilter + QLatin1String(";;") + anyFilesFilter);
     if (!files.empty())
         if (const KSharedConfig::Ptr config = KSharedConfig::openConfig()) {
             KConfigGroup group(config, "Import Certificate");
