@@ -95,7 +95,11 @@ public:
     /** Remove a recipient group */
     void removeRecipient(const Kleo::KeyGroup &group);
 
-    /** Validate that each line edit with content has a key. */
+    /** Returns true if all required information has been entered. */
+    bool isComplete() const;
+
+    /** Returns true if all recipients have been resolved. Otherwise, shows
+        an error message and returns false. */
     bool validate();
 
 protected Q_SLOTS:
@@ -118,6 +122,9 @@ Q_SIGNALS:
 
 private:
     CertificateLineEdit* addRecipientWidget();
+    /** Inserts a new recipient widget after widget @p after or at the end
+     *  if @p after is null. */
+    CertificateLineEdit* insertRecipientWidget(CertificateLineEdit *after);
     void onProtocolChanged();
     void updateCheckBoxes();
 
