@@ -31,7 +31,7 @@
 
 #include <gpgme++/key.h>
 
-#include <kmime/kmime_header_parsing.h>
+#include <KMime/HeaderParsing>
 
 #include <KLocalizedString>
 
@@ -172,7 +172,7 @@ static bool is_de_vs_compliant(bool sign, bool encrypt, const std::vector<Sender
     if (sign) {
         for (const auto &sender: senders) {
             const auto &key = sender.resolvedSigningKey(presetProtocol);
-            if (!IS_DE_VS(key) || keyValidity(key) < GpgME::UserID::Validity::Full) {
+            if (!key.isDeVs() || keyValidity(key) < GpgME::UserID::Validity::Full) {
                 return false;
             }
         }
@@ -181,14 +181,14 @@ static bool is_de_vs_compliant(bool sign, bool encrypt, const std::vector<Sender
     if (encrypt) {
         for (const auto &sender: senders) {
             const auto &key = sender.resolvedSigningKey(presetProtocol);
-            if (!IS_DE_VS(key) || keyValidity(key) < GpgME::UserID::Validity::Full) {
+            if (!key.isDeVs() || keyValidity(key) < GpgME::UserID::Validity::Full) {
                 return false;
             }
         }
 
         for (const auto &recipient: recipients) {
             const auto &key = recipient.resolvedEncryptionKey(presetProtocol);
-            if (!IS_DE_VS(key) || keyValidity(key) < GpgME::UserID::Validity::Full) {
+            if (!key.isDeVs() || keyValidity(key) < GpgME::UserID::Validity::Full) {
                 return false;
             }
         }
@@ -393,11 +393,12 @@ void NewSignEncryptEMailController::startResolveCertificates(const std::vector<M
     d->dialog->pickProtocol();
     d->dialog->setConflict(conflict);
 
-    const bool compliant = !Kleo::gpgComplianceP("de-vs") || is_de_vs_compliant(d->sign,
-                                                                                d->encrypt,
-                                                                                senders,
-                                                                                recipients,
-                                                                                d->presetProtocol);
+    const bool compliant = !Kleo::gnupgUsesDeVsCompliance() ||
+                           (Kleo::gnupgIsDeVsCompliant() && is_de_vs_compliant(d->sign,
+                                                                               d->encrypt,
+                                                                               senders,
+                                                                               recipients,
+                                                                               d->presetProtocol));
 
     if (quickMode && !conflict && compliant) {
         QMetaObject::invokeMethod(this, "slotDialogAccepted", Qt::QueuedConnection);
