@@ -45,40 +45,24 @@ CertifyCertificateDialog::CertifyCertificateDialog(QWidget *p, Qt::WindowFlags f
     mCertWidget = new CertifyWidget(this);
     mainLay->addWidget(mCertWidget);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox();
+    auto buttonBox = new QDialogButtonBox{this};
     buttonBox->setStandardButtons(QDialogButtonBox::Cancel |
                                   QDialogButtonBox::Ok);
-    KGuiItem::assign(buttonBox->button(QDialogButtonBox::Ok), KStandardGuiItem::ok());
+    const auto okButton = buttonBox->button(QDialogButtonBox::Ok);
+    KGuiItem::assign(okButton, KStandardGuiItem::ok());
+    okButton->setText(i18n("Certify"));
     KGuiItem::assign(buttonBox->button(QDialogButtonBox::Cancel), KStandardGuiItem::cancel());
-
-    buttonBox->button(QDialogButtonBox::Ok)->setText(i18n("Certify"));
-    connect(buttonBox->button(QDialogButtonBox::Ok), &QAbstractButton::clicked,
-            this, [this] () {
-        KConfigGroup conf(KSharedConfig::openConfig(), "CertifySettings");
-        const auto lastKey = mCertWidget->secKey();
-        // Do not accept if the keys are the same.
-        if (!lastKey.isNull() && !mCertWidget->target().isNull() &&
-            !strcmp(lastKey.primaryFingerprint(),
-                    mCertWidget->target().primaryFingerprint())) {
-            KMessageBox::error(this, i18n("You cannot certify using the same key."),
-                               i18n("Invalid Selection"), KMessageBox::Notify);
-            return;
-        }
-
-        if (!lastKey.isNull()) {
-            conf.writeEntry("LastKey", lastKey.primaryFingerprint());
-        }
-        conf.writeEntry("ExportCheckState", mCertWidget->exportableSelected());
-        conf.writeEntry("PublishCheckState", mCertWidget->publishSelected());
-        accept();
-    });
-    connect(buttonBox->button(QDialogButtonBox::Cancel), &QAbstractButton::clicked,
-            this, [this] () {
-        close();
-    });
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &CertifyCertificateDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::close);
 
     mainLay->addWidget(buttonBox);
-    KConfigGroup cfgGroup(KSharedConfig::openConfig(), "CertifyDialog");
+
+    okButton->setEnabled(mCertWidget->isValid());
+    connect(mCertWidget, &CertifyWidget::changed, this, [this, okButton] () {
+        okButton->setEnabled(mCertWidget->isValid());
+    });
+
+    KConfigGroup cfgGroup(KSharedConfig::openStateConfig(), "CertifyDialog");
     const QByteArray geom = cfgGroup.readEntry("geometry", QByteArray());
     if (!geom.isEmpty()) {
         restoreGeometry(geom);
@@ -89,7 +73,7 @@ CertifyCertificateDialog::CertifyCertificateDialog(QWidget *p, Qt::WindowFlags f
 
 CertifyCertificateDialog::~CertifyCertificateDialog()
 {
-    KConfigGroup cfgGroup(KSharedConfig::openConfig(), "CertifyDialog");
+    KConfigGroup cfgGroup(KSharedConfig::openStateConfig(), "CertifyDialog");
     cfgGroup.writeEntry("geometry", saveGeometry());
     cfgGroup.sync();
 }
@@ -105,9 +89,14 @@ bool CertifyCertificateDialog::exportableCertificationSelected() const
     return mCertWidget->exportableSelected();
 }
 
-bool CertifyCertificateDialog::trustCertificationSelected() const
+bool CertifyCertificateDialog::trustSignatureSelected() const
 {
-    return false;
+    return mCertWidget->trustSignatureSelected();
+}
+
+QString CertifyCertificateDialog::trustSignatureDomain() const
+{
+    return mCertWidget->trustSignatureDomain();
 }
 
 bool CertifyCertificateDialog::nonRevocableCertificationSelected() const
@@ -148,3 +137,25 @@ QString CertifyCertificateDialog::tags() const
 {
     return mCertWidget->tags();
 }
+
+QDate CertifyCertificateDialog::expirationDate() const
+{
+    return mCertWidget->expirationDate();
+}
+
+void CertifyCertificateDialog::accept()
+{
+    if (!mCertWidget->isValid()) {
+        return;
+    }
+
+    KConfigGroup conf(KSharedConfig::openConfig(), "CertifySettings");
+    const auto lastKey = mCertWidget->secKey();
+    if (!lastKey.isNull()) {
+        conf.writeEntry("LastKey", lastKey.primaryFingerprint());
+    }
+    conf.writeEntry("ExportCheckState", mCertWidget->exportableSelected());
+    conf.writeEntry("PublishCheckState", mCertWidget->publishSelected());
+
+    QDialog::accept();
+}
