@@ -12,6 +12,8 @@
 #include "aboutdata.h"
 #include "settings.h"
 
+#include <interfaces/focusfirstchild.h>
+
 #include "view/padwidget.h"
 #include "view/searchbar.h"
 #include "view/tabwidget.h"
@@ -33,6 +35,8 @@
 #include "utils/action_data.h"
 #include "utils/filedialog.h"
 #include "utils/clipboardmenu.h"
+#include "utils/gui-helper.h"
+#include "utils/qt-cxx20-compat.h"
 
 #include "dialogs/updatenotification.h"
 
@@ -49,6 +53,7 @@
 #include <KMessageBox>
 #include <KStandardGuiItem>
 #include <KShortcutsDialog>
+#include <KToolBar>
 #include <KEditToolBar>
 #include "kleopatra_debug.h"
 #include <KConfigGroup>
@@ -76,6 +81,7 @@
 #include <Libkleo/Classify>
 #include <Libkleo/KeyCache>
 #include <Libkleo/DocAction>
+#include <Libkleo/SystemInfo>
 
 #include <vector>
 #include <KSharedConfig>
@@ -110,6 +116,51 @@ static const std::vector<QString> mainViewActionNames = {
     QStringLiteral("manage_smartcard"),
     QStringLiteral("pad_view")
 };
+
+class CertificateView : public QWidget, public FocusFirstChild
+{
+    Q_OBJECT
+public:
+    CertificateView(QWidget* parent = nullptr)
+        : QWidget{parent}
+        , ui{this}
+    {
+    }
+
+    SearchBar *searchBar() const
+    {
+        return ui.searchBar;
+    }
+
+    TabWidget *tabWidget() const
+    {
+        return ui.tabWidget;
+    }
+
+    void focusFirstChild(Qt::FocusReason reason) override
+    {
+        ui.searchBar->lineEdit()->setFocus(reason);
+    }
+
+private:
+    struct UI {
+        TabWidget *tabWidget = nullptr;
+        SearchBar *searchBar = nullptr;
+        explicit UI(CertificateView *q)
+        {
+            auto vbox = new QVBoxLayout{q};
+            vbox->setSpacing(0);
+
+            searchBar = new SearchBar{q};
+            vbox->addWidget(searchBar);
+            tabWidget = new TabWidget{q};
+            vbox->addWidget(tabWidget);
+
+            tabWidget->connectSearchBar(searchBar);
+        }
+    } ui;
+};
+
 }
 
 class MainWindow::Private
@@ -179,7 +230,7 @@ public:
     void updateSearchBarClickMessage()
     {
         const QString shortcutStr = focusToClickSearchAction->shortcut().toString();
-        ui.searchBar->updateClickMessage(shortcutStr);
+        ui.searchTab->searchBar()->updateClickMessage(shortcutStr);
     }
 
     void updateStatusBar()
@@ -187,14 +238,16 @@ public:
         if (Kleo::gnupgUsesDeVsCompliance()) {
             auto statusBar = std::make_unique<QStatusBar>();
             auto statusLbl = std::make_unique<QLabel>(Formatting::deVsString(Kleo::gnupgIsDeVsCompliant()));
-            const auto color = KColorScheme(QPalette::Active, KColorScheme::View).foreground(
-                Kleo::gnupgIsDeVsCompliant() ? KColorScheme::NormalText: KColorScheme::NegativeText
-            ).color();
-            const auto background = KColorScheme(QPalette::Active, KColorScheme::View).background(
-                Kleo::gnupgIsDeVsCompliant() ? KColorScheme::PositiveBackground : KColorScheme::NegativeBackground
-            ).color();
-            statusLbl->setStyleSheet(QStringLiteral("QLabel { color: %1; background-color: %2; }").
-                                     arg(color.name()).arg(background.name()));
+            if (!SystemInfo::isHighContrastModeActive()) {
+                const auto color = KColorScheme(QPalette::Active, KColorScheme::View).foreground(
+                    Kleo::gnupgIsDeVsCompliant() ? KColorScheme::NormalText: KColorScheme::NegativeText
+                ).color();
+                const auto background = KColorScheme(QPalette::Active, KColorScheme::View).background(
+                    Kleo::gnupgIsDeVsCompliant() ? KColorScheme::PositiveBackground : KColorScheme::NegativeBackground
+                ).color();
+                statusLbl->setStyleSheet(QStringLiteral("QLabel { color: %1; background-color: %2; }").
+                                        arg(color.name()).arg(background.name()));
+            }
             statusBar->insertPermanentWidget(0, statusLbl.release());
             q->setStatusBar(statusBar.release());  // QMainWindow takes ownership
         } else {
@@ -250,7 +303,7 @@ public:
 
     void slotFocusQuickSearch()
     {
-        ui.searchBar->lineEdit()->setFocus();
+        ui.searchTab->searchBar()->lineEdit()->setFocus();
     }
 
     void showView(const QString &actionName, QWidget *widget)
@@ -264,12 +317,18 @@ public:
             }
         }
         ui.stackWidget->setCurrentWidget(widget);
+        if (auto ffci = dynamic_cast<Kleo::FocusFirstChild *>(widget)) {
+            ffci->focusFirstChild(Qt::TabFocusReason);
+        }
     }
 
     void showCertificateView()
     {
-        showView(QStringLiteral("view_certificate_overview"),
-                 KeyCache::instance()->keys().empty() ? ui.welcomeWidget : ui.searchTab);
+        if (KeyCache::instance()->keys().empty()) {
+            showView(QStringLiteral("view_certificate_overview"), ui.welcomeWidget);
+        } else {
+            showView(QStringLiteral("view_certificate_overview"), ui.searchTab);
+        }
     }
 
     void showSmartcardView()
@@ -297,7 +356,7 @@ private:
 
     QAbstractItemView *currentView() const
     {
-        return ui.tabWidget.currentView();
+        return ui.searchTab->tabWidget()->currentView();
     }
 
     void keyListingDone()
@@ -313,48 +372,37 @@ private:
     Kleo::KeyListController controller;
     bool firstShow : 1;
     struct UI {
-        QWidget *searchTab;
-        TabWidget tabWidget;
-        SearchBar *searchBar;
-        PadWidget *padWidget;
-        SmartCardWidget *scWidget;
-        WelcomeWidget *welcomeWidget;
-        QStackedWidget *stackWidget;
+        CertificateView *searchTab = nullptr;
+        PadWidget *padWidget = nullptr;
+        SmartCardWidget *scWidget = nullptr;
+        WelcomeWidget *welcomeWidget = nullptr;
+        QStackedWidget *stackWidget = nullptr;
         explicit UI(MainWindow *q);
     } ui;
-    QAction *focusToClickSearchAction;
-    ClipboardMenu *clipboadMenu;
+    QAction *focusToClickSearchAction = nullptr;
+    ClipboardMenu *clipboadMenu = nullptr;
 };
 
 MainWindow::Private::UI::UI(MainWindow *q)
-    : tabWidget(q), padWidget(nullptr)
+    : padWidget(nullptr)
 {
-    KDAB_SET_OBJECT_NAME(tabWidget);
-
-    searchTab = new QWidget;
-    auto vbox = new QVBoxLayout(searchTab);
-    vbox->setSpacing(0);
-    searchBar = new SearchBar;
-    vbox->addWidget(searchBar);
-    tabWidget.connectSearchBar(searchBar);
-    vbox->addWidget(&tabWidget);
-
-    auto mainWidget = new QWidget;
+    auto mainWidget = new QWidget{q};
     auto mainLayout = new QVBoxLayout(mainWidget);
-    stackWidget = new QStackedWidget;
-
-    mainLayout->addWidget(stackWidget);
+    stackWidget = new QStackedWidget{q};
 
+    searchTab = new CertificateView{q};
     stackWidget->addWidget(searchTab);
 
     new KeyCacheOverlay(mainWidget, q);
 
-    scWidget = new SmartCardWidget();
+    scWidget = new SmartCardWidget{q};
     stackWidget->addWidget(scWidget);
 
-    welcomeWidget = new WelcomeWidget();
+    welcomeWidget = new WelcomeWidget{q};
     stackWidget->addWidget(welcomeWidget);
 
+    mainLayout->addWidget(stackWidget);
+
     q->setCentralWidget(mainWidget);
 }
 
@@ -374,10 +422,10 @@ MainWindow::Private::Private(MainWindow *qq)
 
     controller.setFlatModel(flatModel);
     controller.setHierarchicalModel(hierarchicalModel);
-    controller.setTabWidget(&ui.tabWidget);
+    controller.setTabWidget(ui.searchTab->tabWidget());
 
-    ui.tabWidget.setFlatModel(flatModel);
-    ui.tabWidget.setHierarchicalModel(hierarchicalModel);
+    ui.searchTab->tabWidget()->setFlatModel(flatModel);
+    ui.searchTab->tabWidget()->setHierarchicalModel(hierarchicalModel);
 
     setupActions();
 
@@ -391,6 +439,21 @@ MainWindow::Private::Private(MainWindow *qq)
 
     q->createGUI(QStringLiteral("kleopatra.rc"));
 
+    // make toolbar buttons accessible by keyboard
+    if (auto toolbar = q->findChild<KToolBar*>()) {
+        auto toolbarButtons = toolbar->findChildren<QToolButton*>();
+        for (auto b : toolbarButtons) {
+            b->setFocusPolicy(Qt::TabFocus);
+        }
+        // move toolbar and its child widgets before the central widget in the tab order;
+        // this is necessary to make Shift+Tab work as expected
+        forceSetTabOrder(q, toolbar);
+        auto toolbarChildren = toolbar->findChildren<QWidget*>();
+        std::for_each(std::rbegin(toolbarChildren), std::rend(toolbarChildren), [toolbar](auto w) {
+            forceSetTabOrder(toolbar, w);
+        });
+    }
+
     q->setAcceptDrops(true);
 
     // set default window size
@@ -424,42 +487,42 @@ void MainWindow::Private::setupActions()
 #ifndef Q_OS_WIN
         {
             "tools_start_kwatchgnupg", i18n("GnuPG Log Viewer"), QString(),
-            "kwatchgnupg", q, SLOT(gnupgLogViewer()), QString(), false, true
+            "kwatchgnupg", q, [this](bool) { gnupgLogViewer(); }, QString()
         },
 #endif
         {
             "tools_restart_backend", i18nc("@action:inmenu", "Restart Background Processes"),
             i18nc("@info:tooltip", "Restart the background processes, e.g. after making changes to the configuration."),
-            "view-refresh", q, SLOT(restartDaemons()), {}, false, true
+            "view-refresh", q, [this](bool) { restartDaemons(); }, {}
         },
         // Help menu
 #ifdef Q_OS_WIN
         {
             "help_check_updates", i18n("Check for updates"), QString(),
-            "gpg4win-compact", q, SLOT(forceUpdateCheck()), QString(), false, true
+            "gpg4win-compact", q, [this](bool) { forceUpdateCheck(); }, QString()
         },
 #endif
         // View menu
         {
             "view_certificate_overview", i18nc("@action show certificate overview", "Certificates"),
-            i18n("Show certificate overview"), "view-certificate", q, SLOT(showCertificateView()), QString(), false, true
+            i18n("Show certificate overview"), "view-certificate", q, [this](bool) { showCertificateView(); }, QString()
         },
         {
             "pad_view", i18nc("@action show input / output area for encrypting/signing resp. decrypting/verifying text", "Notepad"),
-            i18n("Show pad for encrypting/decrypting and signing/verifying text"), "note", q, SLOT(showPadView()), QString(), false, true
+            i18n("Show pad for encrypting/decrypting and signing/verifying text"), "note", q, [this](bool) { showPadView(); }, QString()
         },
         {
             "manage_smartcard", i18nc("@action show smartcard management view", "Smartcards"),
-            i18n("Show smartcard management"), "auth-sim-locked", q, SLOT(showSmartcardView()), QString(), false, true
+            i18n("Show smartcard management"), "auth-sim-locked", q, [this](bool) { showSmartcardView(); }, QString()
         },
         // Settings menu
         {
             "settings_self_test", i18n("Perform Self-Test"), QString(),
-            nullptr, q, SLOT(selfTest()), QString(), false, true
+            nullptr, q, [this](bool) { selfTest(); }, QString()
         },
         {
             "configure_groups", i18n("Configure Groups..."), QString(),
-            "group", q, SLOT(configureGroups()), QString(), false, true
+            "group", q, [this](bool) { configureGroups(); }, QString()
         }
     };
 
@@ -537,7 +600,7 @@ void MainWindow::Private::setupActions()
 
     controller.createActions(coll);
 
-    ui.tabWidget.createActions(coll);
+    ui.searchTab->tabWidget()->createActions(coll);
 }
 
 void MainWindow::Private::slotConfigCommitted()
@@ -577,7 +640,7 @@ void MainWindow::closeEvent(QCloseEvent *e)
         }
     }
     if (isQuitting || qApp->isSavingSession()) {
-        d->ui.tabWidget.saveViews(KSharedConfig::openConfig().data());
+        d->ui.searchTab->tabWidget()->saveViews(KSharedConfig::openConfig().data());
         KConfigGroup grp(KConfigGroup(KSharedConfig::openConfig(), autoSaveGroup()));
         saveMainWindowSettings(grp);
         e->accept();
@@ -591,14 +654,13 @@ void MainWindow::showEvent(QShowEvent *e)
 {
     KXmlGuiWindow::showEvent(e);
     if (d->firstShow) {
-        d->ui.tabWidget.loadViews(KSharedConfig::openConfig().data());
+        d->ui.searchTab->tabWidget()->loadViews(KSharedConfig::openConfig().data());
         d->firstShow = false;
     }
 
     if (!savedGeometry.isEmpty()) {
         restoreGeometry(savedGeometry);
     }
-
 }
 
 void MainWindow::hideEvent(QHideEvent *e)
@@ -716,4 +778,5 @@ void MainWindow::saveProperties(KConfigGroup &cg)
     cg.writeEntry("hidden", isHidden());
 }
 
+#include "mainwindow.moc"
 #include "moc_mainwindow.cpp"
