@@ -10,10 +10,13 @@
 
 #include "kleopatra_debug.h"
 
+#include <settings.h>
+
 #include <Libkleo/KleoException>
 #include <Libkleo/Classify>
 #include <Libkleo/KeyCache>
 #include <Libkleo/Formatting>
+#include <Libkleo/SystemInfo>
 
 #include "crypto/gui/signencryptwidget.h"
 #include "crypto/gui/resultitemwidget.h"
@@ -70,6 +73,8 @@ static GpgME::Protocol getProtocol(const std::shared_ptr<const Kleo::Crypto::Tas
 
 class PadWidget::Private
 {
+    friend class ::Kleo::PadWidget;
+
 public:
     Private(PadWidget *qq):
         q(qq),
@@ -158,7 +163,7 @@ public:
         mEdit->setAcceptRichText(false);
         mEdit->setMinimumWidth(QFontMetrics(fixedFont).averageCharWidth() * 70);
 
-        if (KeyCache::instance()->pgpOnly()) {
+        if (KeyCache::instance()->pgpOnly() || !Settings{}.cmsEnabled()) {
             mSigEncWidget->setProtocol(GpgME::OpenPGP);
         } else {
             auto grp = new QButtonGroup(q);
@@ -271,7 +276,6 @@ public:
     void cryptDone(const std::shared_ptr<const Kleo::Crypto::Task::Result> &result)
     {
         updateCommitButton();
-        mDecryptBtn->setEnabled(true);
         mProgressBar->setVisible(false);
         mProgressLabel->setVisible(false);
 
@@ -309,6 +313,7 @@ public:
         mEdit->setPlainText(QString::fromUtf8(mOutputData));
         mOutputData.clear();
         mRevertBtn->setVisible(true);
+        mDecryptBtn->setEnabled(true);
 
         const auto decryptVerifyResult = dynamic_cast<const Kleo::Crypto::DecryptVerifyResult*>(result.get());
         if (decryptVerifyResult) {
@@ -344,8 +349,7 @@ public:
             KMessageBox::error(q,
                     e.message(),
                     i18nc("@title", "Error in crypto action"));
-            mCryptBtn->setEnabled(true);
-            mDecryptBtn->setEnabled(true);
+            updateCommitButton();
             mProgressBar->setVisible(false);
             mProgressLabel->setVisible(false);
             return;
@@ -491,16 +495,20 @@ public:
             mCryptBtn->setIcon(QIcon::fromTheme(de_vs
                         ? QStringLiteral("security-high")
                         : QStringLiteral("security-medium")));
-            mCryptBtn->setStyleSheet(QStringLiteral("QPushButton { background-color: %1; }").arg(de_vs
-                        ? KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::PositiveBackground).color().name()
-                        : KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NegativeBackground).color().name()));
+            if (!SystemInfo::isHighContrastModeActive()) {
+                mCryptBtn->setStyleSheet(QStringLiteral("QPushButton { background-color: %1; }").arg(de_vs
+                            ? KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::PositiveBackground).color().name()
+                            : KColorScheme(QPalette::Active, KColorScheme::View).background(KColorScheme::NegativeBackground).color().name()));
+            }
             mAdditionalInfoLabel->setText(de_vs
                     ? i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
                         "%1 communication possible.", Formatting::deVsString())
                     : i18nc("%1 is a placeholder for the name of a compliance mode. E.g. NATO RESTRICTED compliant or VS-NfD compliant",
                         "%1 communication not possible.", Formatting::deVsString()));
             mAdditionalInfoLabel->setVisible(true);
-            mCryptBtn->setEnabled(false);
+            if (!Kleo::gnupgIsDeVsCompliant()) {
+                mCryptBtn->setEnabled(false);
+            }
             mMessageWidget->setVisible(!Kleo::gnupgIsDeVsCompliant());
         }
     }
@@ -531,3 +539,8 @@ PadWidget::PadWidget(QWidget *parent):
     d(new Private(this))
 {
 }
+
+void PadWidget::focusFirstChild(Qt::FocusReason reason)
+{
+    d->mEdit->setFocus(reason);
+}
